__author__ = "Oscar de Felice"
__email__ = "oscar.defelice@gmail.com"
__copyright__ = "(c) 2023 Oscar de Felice"

__license__ = "MIT"
__version__ = "1.0.4"
__title__ = 'GIT Message Hook'
__description__ = 'Force conventional git commit messages for git repositories, by leveraging git hooks.'



import shutil, os

def main():
	if not os.path.isdir('.git'):
		print('error: .git directory not found in the current path. this is not a git repository?')
		return
	
	template_path = os.path.expanduser("~/.git-templates/hooks/commit-msg")
	if shutil.which('git') == None:
		print('error: git not found on path. please install git and then run pip install --upgrade git-message-hook')
		return
	if not os.path.exists(template_path):
		print('error: git hooks template not found on %s, please run pip install git-message-hook' % template_path)
		return
	shutil.copy(template_path, ".git/hooks/")
	print("success: conventional git messages are enforced")

if __name__ == "__main__":
	main()


#!/usr/bin/env python3
import os, sys
import git_message_hook
from git_message_hook import __version__, __description__, __author__, __email__, __license__, __title__
from setuptools import setup, find_packages
from setuptools.command.install import install

import site
from distutils.dir_util import copy_tree

pypi_name = "git-message-hook"
pkg_name = "git_message_hook"

class PostInstallCommand(install):
	"""Post-installation for installation mode."""
	def run(self):
		os.system("echo CUSTOM_PRE_MESSAGE")
		install.run(self)
		os.system("echo CUSTOM_POST_MESSAGE")
		#conf_path_temp = resource_filename(Requirement.parse(pypi_name), "git-templates")
		#the_path = site.getusersitepackages() # => Useless and misleading
		fpath = os.path.join(self.install_lib, pkg_name)
		fpath = os.path.join(fpath, "git-templates")
		tpath = os.path.join(os.path.expanduser("~"), ".git-templates")
		os.system("git config --global init.templatedir ~/.git-templates")
		copy_tree(fpath, tpath)

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

s = setup(
	name=pypi_name,
	version=__version__,
	license=__license__,
	description=__description__,
	long_description=read("README.md"),
	long_description_content_type='text/markdown',
	keywords="security,scanner",
	url='https://github.com/oscar-defelice/%s' % pypi_name,
	packages=find_packages(),
	include_package_data=True,
	entry_points={
		"console_scripts": [
			"git-message-hook = git_message_hook.main:main",
		],
	},
	install_requires=[],
	python_requires = ">= 3.4",
	author=__author__,
	author_email=__email__,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
	cmdclass={
		'install': PostInstallCommand,
	},
	)

